# Meltano: ELT for the DataOps era

[![pipeline status](https://gitlab.com/meltano/meltano/badges/master/pipeline.svg)](https://gitlab.com/meltano/meltano/commits/master)

[Meltano](https://meltano.com) is
[open source](https://gitlab.com/meltano/meltano),
[self-hosted](https://meltano.com/docs/production.html),
[CLI-first](https://meltano.com/docs/command-line-interface.html),
[debuggable](https://meltano.com/docs/command-line-interface.html#debugging), and
[extensible](https://meltano.com/docs/plugins.html).

[Pipelines are code](https://meltano.com/docs/project.html),
ready to be version controlled,
[containerized](https://meltano.com/docs/containerization.html), and
[deployed continuously](https://meltano.com/docs/production.html#and-onto-the-production-environment).
Develop and test
[locally](https://meltano.com/docs/getting-started.html#local-installation),
then
[deploy in production](https://meltano.com/docs/production.html)
along with the built-in
[Airflow integration](https://meltano.com/docs/production.html#airflow-orchestrator),
or inside your
[orchestrator of choice](https://meltano.com/docs/production.html#meltano-elt).

Meltano [embraces](/docs/#embracing-singer) the [Singer](https://www.singer.io/) standard and its community-maintained library of open source
[extractors](https://hub.meltano.com/extractors/) and
[loaders](https://hub.meltano.com/loaders/),
and leverages [dbt](https://www.getdbt.com) for [transformation](https://meltano.com/docs/transforms.html).

## Documentation

Check out the ["Getting Started" guide](https://meltano.com/docs/getting-started.html)
or find the full documentation at <https://www.meltano.com/docs/>.

## Contributing to Meltano

We welcome contributions and improvements, please see the [contribution guidelines](https://meltano.com/docs/contributor-guide.html)

## Responsible Disclosure Policy

Please refer to the [responsible disclosure policy](https://meltano.com/docs/responsible-disclosure.html) on our website.

## License

This code is distributed under the MIT license, see the [LICENSE](LICENSE) file.
